//
// Copyright (c) 2003, 2017, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2013, Red Hat Inc.
// All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/ad_aarch64.hpp"

//------------------Pipeline Methods-----------------------------------------
#ifndef PRODUCT
const char * Pipeline::stageName(uint s) {
  static const char * const _stage_names[] = {
    "undefined", "S0", "S1", "S2", "S3", "S4", "S5"
  };

  return (s <= 6 ? _stage_names[s] : "???");
}
#endif

uint Pipeline::functional_unit_latency(uint start, const Pipeline *pred) const {
  // See if the functional units overlap
  uint mask = resourcesUsedExclusively() & pred->resourcesUsedExclusively();
  if (mask == 0)
    return (start);

  for (uint i = 0; i < pred->resourceUseCount(); i++) {
    const Pipeline_Use_Element *predUse = pred->resourceUseElement(i);
    if (predUse->multiple())
      continue;

    for (uint j = 0; j < resourceUseCount(); j++) {
      const Pipeline_Use_Element *currUse = resourceUseElement(j);
      if (currUse->multiple())
        continue;

      if (predUse->used() & currUse->used()) {
        Pipeline_Use_Cycle_Mask x = predUse->mask();
        Pipeline_Use_Cycle_Mask y = currUse->mask();

        for ( y <<= start; x.overlaps(y); start++ )
          y <<= 1;
      }
    }
  }

  // There is the potential for overlap
  return (start);
}

// The following two routines assume that the root Pipeline_Use entity
// consists of exactly 1 element for each functional unit
// start is relative to the current cycle; used for latency-based info
uint Pipeline_Use::full_latency(uint delay, const Pipeline_Use &pred) const {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      uint min_delay = 7;
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        uint curr_delay = delay;
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= curr_delay; x.overlaps(y); curr_delay++ )
            y <<= 1;
        }
        if (min_delay > curr_delay)
          min_delay = curr_delay;
      }
      if (delay < min_delay)
      delay = min_delay;
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= delay; x.overlaps(y); delay++ )
            y <<= 1;
        }
      }
    }
  }

  return (delay);
}

void Pipeline_Use::add_usage(const Pipeline_Use &pred) {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        if ( !predUse->_mask.overlaps(currUse->_mask) ) {
          currUse->_used |= (1 << j);
          _resources_used |= (1 << j);
          currUse->_mask.Or(predUse->_mask);
          break;
        }
      }
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        currUse->_used |= (1 << j);
        _resources_used |= (1 << j);
        currUse->_mask.Or(predUse->_mask);
      }
    }
  }
}

uint Pipeline::operand_latency(uint opnd, const Pipeline *pred) const {
  int const default_latency = 1;

  assert(this, "NULL pipeline info");
  assert(pred, "NULL predecessor pipline info");

  if (pred->hasFixedLatency())
    return (pred->fixedLatency());

  // If this is not an operand, then assume a dependence with 0 latency
  if (opnd > _read_stage_count)
    return (0);

  uint writeStage = pred->_write_stage;
  uint readStage  = _read_stages[opnd-1];

  if (writeStage == stage_undefined || readStage == stage_undefined)
    return (default_latency);

  int delta = writeStage - readStage;
  if (delta < 0) delta = 0;

  return (delta);
}

Pipeline_Use_Cycle_Mask operator&(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask & in2._mask);
}

Pipeline_Use_Cycle_Mask operator|(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask | in2._mask);
}

static const Pipeline pipeline_class_Zero_Instructions(0, 0, true, 0, 0, false, false, false, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

static const Pipeline pipeline_class_Unknown_Instructions(0, 0, true, 0, 0, false, true, true, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

const Pipeline_Use_Element Pipeline_Use::elaborated_elements[9] = {
  Pipeline_Use_Element(0, 0, 0, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 1, 1, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 2, 2, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 3, 3, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 4, 4, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 5, 5, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 6, 6, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 7, 7, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 8, 8, false, Pipeline_Use_Cycle_Mask(0))
};

const Pipeline_Use Pipeline_Use::elaborated_use(0, 0, 9, (Pipeline_Use_Element *)&elaborated_elements[0]);


// Pipeline Class "fp_dop_reg_reg_s"
static const enum machPipelineStages pipeline_reads_001[2] = {
  stage_S1,
  stage_S2 
};

static const enum machPipelineStages pipeline_res_stages_001[9] = {
  stage_S0,        // INS0
  stage_S0,        // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_S5         // BRANCH
};

static const uint pipeline_res_cycles_001[9] = {
  1, // INS0
  1, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  1  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_001[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x00000010)) 
};

static const Pipeline pipeline_class_001((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_dop_reg_reg_d"
static const Pipeline pipeline_class_002((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_uop_s"
static const enum machPipelineStages pipeline_reads_002[1] = {
  stage_S1 
};

static const Pipeline pipeline_class_003((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_uop_d"
static const Pipeline pipeline_class_004((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_d2f"
static const Pipeline pipeline_class_005((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_f2d"
static const Pipeline pipeline_class_006((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_f2i"
static const Pipeline pipeline_class_007((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_f2l"
static const Pipeline pipeline_class_008((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_i2f"
static const Pipeline pipeline_class_009((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_l2f"
static const Pipeline pipeline_class_010((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_d2i"
static const Pipeline pipeline_class_011((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_d2l"
static const Pipeline pipeline_class_012((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_i2d"
static const Pipeline pipeline_class_013((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_l2d"
static const Pipeline pipeline_class_014((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "fp_div_s"
static const enum machPipelineStages pipeline_res_stages_002[9] = {
  stage_S0,        // INS0
  stage_undefined, // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_S5         // BRANCH
};

static const uint pipeline_res_cycles_002[9] = {
  1, // INS0
  0, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  1  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_002[2] = {
  Pipeline_Use_Element(0x001, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x00000010)) 
};

static const Pipeline pipeline_class_015((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "fp_div_d"
static const Pipeline pipeline_class_016((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "fp_cond_reg_reg_s"
static const enum machPipelineStages pipeline_reads_003[3] = {
  stage_S1,
  stage_S1,
  stage_S1 
};

static const enum machPipelineStages pipeline_res_stages_003[9] = {
  stage_S0,        // INS0
  stage_S0,        // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_S3         // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_003[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_017((uint)stage_S3, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "fp_cond_reg_reg_d"
static const Pipeline pipeline_class_018((uint)stage_S3, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "fp_imm_s"
static const Pipeline pipeline_class_019((uint)stage_S3, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "fp_imm_d"
static const Pipeline pipeline_class_020((uint)stage_S3, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "fp_load_constant_s"
static const enum machPipelineStages pipeline_res_stages_004[9] = {
  stage_S0,        // INS0
  stage_S0,        // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_S4         // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_004[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x00000008)) 
};

static const Pipeline pipeline_class_021((uint)stage_S4, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "fp_load_constant_d"
static const Pipeline pipeline_class_022((uint)stage_S4, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "vmul64"
static const enum machPipelineStages pipeline_reads_004[2] = {
  stage_S1,
  stage_S1 
};

static const Pipeline pipeline_class_023((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "vmul128"
static const Pipeline pipeline_class_024((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "vmla64"
static const Pipeline pipeline_class_025((uint)stage_undefined, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "vmla128"
static const Pipeline pipeline_class_026((uint)stage_undefined, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "vdop64"
static const enum machPipelineStages pipeline_reads_005[2] = {
  stage_S2,
  stage_S2 
};

static const Pipeline pipeline_class_027((uint)stage_S4, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_004[0]));

// Pipeline Class "vdop128"
static const enum machPipelineStages pipeline_res_stages_005[9] = {
  stage_S0,        // INS0
  stage_undefined, // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_S4         // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_005[2] = {
  Pipeline_Use_Element(0x001, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x00000008)) 
};

static const Pipeline pipeline_class_028((uint)stage_S4, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "vlogical64"
static const Pipeline pipeline_class_029((uint)stage_S3, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vlogical128"
static const enum machPipelineStages pipeline_res_stages_006[9] = {
  stage_S0,        // INS0
  stage_undefined, // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_S3         // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_006[2] = {
  Pipeline_Use_Element(0x001, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_030((uint)stage_S3, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_005,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "vshift64"
static const Pipeline pipeline_class_031((uint)stage_S3, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vshift128"
static const Pipeline pipeline_class_032((uint)stage_S3, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "vshift64_imm"
static const enum machPipelineStages pipeline_reads_006[2] = {
  stage_S1,
  stage_undefined 
};

static const Pipeline pipeline_class_033((uint)stage_S3, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_006,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vshift128_imm"
static const Pipeline pipeline_class_034((uint)stage_S3, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_006,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "vdop_fp64"
static const Pipeline pipeline_class_035((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "vdop_fp128"
static const Pipeline pipeline_class_036((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "vmuldiv_fp64"
static const Pipeline pipeline_class_037((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "vmuldiv_fp128"
static const Pipeline pipeline_class_038((uint)stage_S5, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "vsqrt_fp128"
static const Pipeline pipeline_class_039((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "vunop_fp64"
static const Pipeline pipeline_class_040((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "vunop_fp128"
static const Pipeline pipeline_class_041((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "vdup_reg_reg64"
static const Pipeline pipeline_class_042((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vdup_reg_reg128"
static const Pipeline pipeline_class_043((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vdup_reg_freg64"
static const Pipeline pipeline_class_044((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vdup_reg_freg128"
static const Pipeline pipeline_class_045((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vdup_reg_dreg128"
static const Pipeline pipeline_class_046((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vmovi_reg_imm64"
static const Pipeline pipeline_class_047((uint)stage_S3, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vmovi_reg_imm128"
static const Pipeline pipeline_class_048((uint)stage_S3, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x101, 0x101, 2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "vload_reg_mem64"
static const enum machPipelineStages pipeline_reads_007[1] = {
  stage_S0 
};

static const Pipeline pipeline_class_049((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vload_reg_mem128"
static const Pipeline pipeline_class_050((uint)stage_S5, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vstore_reg_mem64"
static const enum machPipelineStages pipeline_reads_008[2] = {
  stage_S2,
  stage_S0 
};

static const Pipeline pipeline_class_051((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_008,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "vstore_reg_mem128"
static const Pipeline pipeline_class_052((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_008,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x103, 0x100, 2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_reg_reg"
static const enum machPipelineStages pipeline_res_stages_007[9] = {
  stage_S0,        // INS0
  stage_S0,        // INS1
  stage_S2,        // INS01
  stage_S2,        // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_003[9] = {
  1, // INS0
  1, // INS1
  1, // INS01
  1, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_007[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x00c, 2, 3, true,  Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_053((uint)stage_S2, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "ialu_reg_reg_shift"
static const enum machPipelineStages pipeline_reads_009[3] = {
  stage_S1,
  stage_S0,
  stage_undefined 
};

static const Pipeline pipeline_class_054((uint)stage_S2, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_009,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "ialu_reg_shift"
static const Pipeline pipeline_class_055((uint)stage_S2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "ialu_reg_reg_vshift"
static const enum machPipelineStages pipeline_reads_010[2] = {
  stage_S0,
  stage_S0 
};

static const enum machPipelineStages pipeline_res_stages_008[9] = {
  stage_S0,        // INS0
  stage_S0,        // INS1
  stage_S1,        // INS01
  stage_S1,        // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_008[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x00c, 2, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)) 
};

static const Pipeline pipeline_class_056((uint)stage_S1, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_010,
   (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_008[0]));

// Pipeline Class "ialu_reg_reg_extr"
static const enum machPipelineStages pipeline_res_stages_009[9] = {
  stage_undefined, // INS0
  stage_S0,        // INS1
  stage_S1,        // INS01
  stage_S1,        // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_004[9] = {
  0, // INS0
  1, // INS1
  1, // INS01
  1, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_009[2] = {
  Pipeline_Use_Element(0x002, 1, 1, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x00c, 2, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)) 
};

static const Pipeline pipeline_class_057((uint)stage_S2, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_010,
   (enum machPipelineStages * const) pipeline_res_stages_009,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x00e, 0x002, 2, (Pipeline_Use_Element *)&pipeline_res_mask_009[0]));

// Pipeline Class "ialu_reg"
static const Pipeline pipeline_class_058((uint)stage_S2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "ialu_reg_imm"
static const Pipeline pipeline_class_059((uint)stage_S2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "ialu_imm"
static const Pipeline pipeline_class_060((uint)stage_S1, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_008[0]));

// Pipeline Class "icmp_reg_reg"
static const Pipeline pipeline_class_061((uint)stage_S2, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "icmp_reg_imm"
static const Pipeline pipeline_class_062((uint)stage_S2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "icond_none"
static const Pipeline pipeline_class_063((uint)stage_S2, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "icond_reg_reg"
static const Pipeline pipeline_class_064((uint)stage_S2, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "icond_reg"
static const Pipeline pipeline_class_065((uint)stage_S2, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_004,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x00f, 0x000, 2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "imul_reg_reg"
static const enum machPipelineStages pipeline_res_stages_010[9] = {
  stage_S0,        // INS0
  stage_S0,        // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_S3,        // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_005[9] = {
  1, // INS0
  1, // INS1
  0, // INS01
  0, // ALU0
  1, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_010[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x010, 4, 4, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_066((uint)stage_S3, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_010,
   (enum machPipelineStages * const) pipeline_res_stages_010,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x013, 0x010, 2, (Pipeline_Use_Element *)&pipeline_res_mask_010[0]));

// Pipeline Class "imac_reg_reg"
static const enum machPipelineStages pipeline_reads_011[3] = {
  stage_S0,
  stage_S0,
  stage_S0 
};

static const Pipeline pipeline_class_067((uint)stage_S3, 3, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_011,
   (enum machPipelineStages * const) pipeline_res_stages_010,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x013, 0x010, 2, (Pipeline_Use_Element *)&pipeline_res_mask_010[0]));

// Pipeline Class "lmul_reg_reg"
static const Pipeline pipeline_class_068((uint)stage_S3, 2, true, 3, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_010,
   (enum machPipelineStages * const) pipeline_res_stages_010,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x013, 0x010, 2, (Pipeline_Use_Element *)&pipeline_res_mask_010[0]));

// Pipeline Class "lmac_reg_reg"
static const Pipeline pipeline_class_069((uint)stage_S3, 3, true, 3, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_011,
   (enum machPipelineStages * const) pipeline_res_stages_010,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x013, 0x010, 2, (Pipeline_Use_Element *)&pipeline_res_mask_010[0]));

// Pipeline Class "idiv_reg_reg"
static const enum machPipelineStages pipeline_res_stages_011[9] = {
  stage_S0,        // INS0
  stage_undefined, // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_S3,        // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_006[9] = {
  1, // INS0
  0, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  1, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_011[2] = {
  Pipeline_Use_Element(0x001, 0, 0, false, Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x020, 5, 5, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_070((uint)stage_S3, 2, true, 8, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_010,
   (enum machPipelineStages * const) pipeline_res_stages_011,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x021, 0x021, 2, (Pipeline_Use_Element *)&pipeline_res_mask_011[0]));

// Pipeline Class "ldiv_reg_reg"
static const Pipeline pipeline_class_071((uint)stage_S3, 2, true, 16, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_010,
   (enum machPipelineStages * const) pipeline_res_stages_011,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x021, 0x021, 2, (Pipeline_Use_Element *)&pipeline_res_mask_011[0]));

// Pipeline Class "iload_prefetch"
static const enum machPipelineStages pipeline_res_stages_012[9] = {
  stage_S0,        // INS0
  stage_S0,        // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_S3,        // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_007[9] = {
  1, // INS0
  1, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  1, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_012[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x080, 7, 7, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_072((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_012,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_012[0]));

// Pipeline Class "iload_reg_mem"
static const Pipeline pipeline_class_073((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_012,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_012[0]));

// Pipeline Class "iload_reg_reg"
static const Pipeline pipeline_class_074((uint)stage_S3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_012,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_012[0]));

// Pipeline Class "istore_mem"
static const Pipeline pipeline_class_075((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_007,
   (enum machPipelineStages * const) pipeline_res_stages_012,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_012[0]));

// Pipeline Class "istore_reg_mem"
static const Pipeline pipeline_class_076((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_008,
   (enum machPipelineStages * const) pipeline_res_stages_012,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_012[0]));

// Pipeline Class "istore_reg_reg"
static const enum machPipelineStages pipeline_reads_012[2] = {
  stage_S0,
  stage_S2 
};

static const Pipeline pipeline_class_077((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_012,
   (enum machPipelineStages * const) pipeline_res_stages_012,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_012[0]));

// Pipeline Class "pipe_branch"
static const enum machPipelineStages pipeline_res_stages_013[9] = {
  stage_S0,        // INS0
  stage_S0,        // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_S1,        // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_008[9] = {
  1, // INS0
  1, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  1, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_013[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000001)),
  Pipeline_Use_Element(0x040, 6, 6, false, Pipeline_Use_Cycle_Mask(0x00000001)) 
};

static const Pipeline pipeline_class_078((uint)stage_undefined, 0, false, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_013,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x043, 0x040, 2, (Pipeline_Use_Element *)&pipeline_res_mask_013[0]));

// Pipeline Class "pipe_branch_cond"
static const Pipeline pipeline_class_079((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_013,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x043, 0x040, 2, (Pipeline_Use_Element *)&pipeline_res_mask_013[0]));

// Pipeline Class "pipe_cmp_branch"
static const Pipeline pipeline_class_080((uint)stage_undefined, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_013,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x043, 0x040, 2, (Pipeline_Use_Element *)&pipeline_res_mask_013[0]));

// Pipeline Class "pipe_serial"
static const uint pipeline_res_cycles_009[9] = {
  2, // INS0
  2, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  1, // DIV
  0  // BRANCH
};

static const Pipeline_Use_Element pipeline_res_mask_014[2] = {
  Pipeline_Use_Element(0x003, 0, 1, true,  Pipeline_Use_Cycle_Mask(0x80000002)),
  Pipeline_Use_Element(0x080, 7, 7, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_081((uint)stage_undefined, 0, true, 16, 1, false, false, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_012,
  (uint * const) pipeline_res_cycles_009,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_014[0]));

// Pipeline Class "pipe_slow"
static const Pipeline pipeline_class_082((uint)stage_undefined, 0, true, 16, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_012,
  (uint * const) pipeline_res_cycles_009,
  Pipeline_Use(0x083, 0x080, 2, (Pipeline_Use_Element *)&pipeline_res_mask_014[0]));

// Pipeline Class "pipe_class_empty"
static const enum machPipelineStages pipeline_res_stages_014[9] = {
  stage_undefined, // INS0
  stage_undefined, // INS1
  stage_undefined, // INS01
  stage_undefined, // ALU0
  stage_undefined, // ALU1
  stage_undefined, // ALU
  stage_undefined, // MAC
  stage_undefined, // DIV
  stage_undefined  // BRANCH
};

static const uint pipeline_res_cycles_010[9] = {
  0, // INS0
  0, // INS1
  0, // INS01
  0, // ALU0
  0, // ALU1
  0, // ALU
  0, // MAC
  0, // DIV
  0  // BRANCH
};

static const Pipeline pipeline_class_083((uint)stage_undefined, 0, true, 0, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_014,
  (uint * const) pipeline_res_cycles_010,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_default"
static const Pipeline pipeline_class_084((uint)stage_undefined, 0, true, 2, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_014,
  (uint * const) pipeline_res_cycles_010,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_compare"
static const Pipeline pipeline_class_085((uint)stage_undefined, 0, true, 16, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_014,
  (uint * const) pipeline_res_cycles_010,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_memory"
static const Pipeline pipeline_class_086((uint)stage_undefined, 0, true, 16, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_014,
  (uint * const) pipeline_res_cycles_010,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_class_call"
static const Pipeline pipeline_class_087((uint)stage_undefined, 0, true, 100, 1, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_014,
  (uint * const) pipeline_res_cycles_010,
  Pipeline_Use(0x000, 0x000, 0, (Pipeline_Use_Element *)NULL));

//------------------Inter-Instruction Latency--------------------------------
uint Node::latency(uint i) {
  uint j;
  // verify in legal range for inputs
  assert(i < len(), "index not in range");

  // verify input is not null
  Node *pred = in(i);
  if (!pred)
    return 0;

  if (pred->is_Proj())
    pred = pred->in(0);

  // if either node does not have pipeline info, use default
  const Pipeline *predpipe = pred->pipeline();
  assert(predpipe, "no predecessor pipeline info");

  if (predpipe->hasFixedLatency())
    return predpipe->fixedLatency();

  const Pipeline *currpipe = pipeline();
  assert(currpipe, "no pipeline info");

  if (!is_Mach())
    return 0;

  const MachNode *m = as_Mach();
  j = m->oper_input_base();
  if (i < j)
    return currpipe->functional_unit_latency(0, predpipe);

  // determine which operand this is in
  uint n = m->num_opnds();
  int delta = 0;

  uint k;
  for (k = 1; k < n; k++) {
    j += m->_opnds[k]->num_edges();
    if (i < j)
      break;
  }
  if (k < n)
    delta = currpipe->operand_latency(k,predpipe);

  return currpipe->functional_unit_latency(delta, predpipe);
}

// Descriptions for emitting different functional unit nops
void Bundle::initialize_nops(MachNode * nop_list[1], Compile *C) {
  nop_list[0] = (MachNode *) new (C) MachNopNode();
};

#ifndef PRODUCT
void Bundle::dump(outputStream *st) const {
  static const char * bundle_flags[] = {
    "",
    "use nop delay",
    "use unconditional delay",
    "use conditional delay",
    "used in conditional delay",
    "used in unconditional delay",
    "used in all conditional delays",
  };

  static const char *resource_names[9] = { "INS0", "INS1", "INS01", "ALU0", "ALU1", "ALU", "MAC", "DIV", "BRANCH" };

  bool needs_comma = false;

  if (_flags) {
    st->print("%s", bundle_flags[_flags]);
    needs_comma = true;
  };
  if (instr_count()) {
    st->print("%s%d instr%s", needs_comma ? ", " : "", instr_count(), instr_count() != 1 ? "s" : "");
    needs_comma = true;
  };
  uint r = resources_used();
  if (r) {
    st->print("%sresource%s:", needs_comma ? ", " : "", (r & (r-1)) != 0 ? "s" : "");
    for (uint i = 0; i < 9; i++)
      if ((r & (1 << i)) != 0)
        st->print(" %s", resource_names[i]);
    needs_comma = true;
  };
  st->print("\n");
}
#endif
const Pipeline *                          Node::pipeline_class() { return (&pipeline_class_Zero_Instructions); }
const Pipeline *                          Node::pipeline() const { return (&pipeline_class_Zero_Instructions); }

const Pipeline *                      MachNode::pipeline_class() { return (&pipeline_class_Unknown_Instructions); }
const Pipeline *                      MachNode::pipeline() const { return pipeline_class(); }

const Pipeline * MachNopNode::pipeline() const { return (&pipeline_class_083); }


const Pipeline *                         loadBNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                         loadBNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                       loadB2LNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                       loadB2LNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                        loadUBNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                        loadUBNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                      loadUB2LNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                      loadUB2LNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                         loadSNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                         loadSNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                       loadS2LNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                       loadS2LNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                        loadUSNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                        loadUSNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                      loadUS2LNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                      loadUS2LNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                         loadINode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                         loadINode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                       loadI2LNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                       loadI2LNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                      loadUI2LNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                      loadUI2LNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                         loadLNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                         loadLNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                     loadRangeNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                     loadRangeNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                         loadPNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                         loadPNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                         loadNNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                         loadNNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                     loadKlassNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                     loadKlassNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                    loadNKlassNode::pipeline_class() { return (&pipeline_class_073); }
const Pipeline *                    loadNKlassNode::pipeline() const { return (&pipeline_class_073); }

const Pipeline *                         loadFNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                         loadFNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                         loadDNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                         loadDNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                      loadConINode::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *                      loadConINode::pipeline() const { return (&pipeline_class_060); }

const Pipeline *                      loadConLNode::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *                      loadConLNode::pipeline() const { return (&pipeline_class_060); }

const Pipeline *                      loadConPNode::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *                      loadConPNode::pipeline() const { return (&pipeline_class_060); }

const Pipeline *                     loadConP0Node::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *                     loadConP0Node::pipeline() const { return (&pipeline_class_060); }

const Pipeline *                     loadConP1Node::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *                     loadConP1Node::pipeline() const { return (&pipeline_class_060); }

const Pipeline *               loadConPollPageNode::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *               loadConPollPageNode::pipeline() const { return (&pipeline_class_060); }

const Pipeline *               loadByteMapBaseNode::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *               loadByteMapBaseNode::pipeline() const { return (&pipeline_class_060); }

const Pipeline *                      loadConNNode::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *                      loadConNNode::pipeline() const { return (&pipeline_class_060); }

const Pipeline *                     loadConN0Node::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *                     loadConN0Node::pipeline() const { return (&pipeline_class_060); }

const Pipeline *                 loadConNKlassNode::pipeline_class() { return (&pipeline_class_060); }
const Pipeline *                 loadConNKlassNode::pipeline() const { return (&pipeline_class_060); }

const Pipeline *               loadConF_packedNode::pipeline_class() { return (&pipeline_class_019); }
const Pipeline *               loadConF_packedNode::pipeline() const { return (&pipeline_class_019); }

const Pipeline *                      loadConFNode::pipeline_class() { return (&pipeline_class_021); }
const Pipeline *                      loadConFNode::pipeline() const { return (&pipeline_class_021); }

const Pipeline *               loadConD_packedNode::pipeline_class() { return (&pipeline_class_020); }
const Pipeline *               loadConD_packedNode::pipeline() const { return (&pipeline_class_020); }

const Pipeline *                      loadConDNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                      loadConDNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                   storeimmCM0Node::pipeline_class() { return (&pipeline_class_075); }
const Pipeline *                   storeimmCM0Node::pipeline() const { return (&pipeline_class_075); }

const Pipeline *           storeimmCM0_orderedNode::pipeline_class() { return (&pipeline_class_075); }
const Pipeline *           storeimmCM0_orderedNode::pipeline() const { return (&pipeline_class_075); }

const Pipeline *                        storeBNode::pipeline_class() { return (&pipeline_class_076); }
const Pipeline *                        storeBNode::pipeline() const { return (&pipeline_class_076); }

const Pipeline *                    storeimmB0Node::pipeline_class() { return (&pipeline_class_075); }
const Pipeline *                    storeimmB0Node::pipeline() const { return (&pipeline_class_075); }

const Pipeline *                        storeCNode::pipeline_class() { return (&pipeline_class_076); }
const Pipeline *                        storeCNode::pipeline() const { return (&pipeline_class_076); }

const Pipeline *                    storeimmC0Node::pipeline_class() { return (&pipeline_class_075); }
const Pipeline *                    storeimmC0Node::pipeline() const { return (&pipeline_class_075); }

const Pipeline *                        storeINode::pipeline_class() { return (&pipeline_class_076); }
const Pipeline *                        storeINode::pipeline() const { return (&pipeline_class_076); }

const Pipeline *                    storeimmI0Node::pipeline_class() { return (&pipeline_class_075); }
const Pipeline *                    storeimmI0Node::pipeline() const { return (&pipeline_class_075); }

const Pipeline *                        storeLNode::pipeline_class() { return (&pipeline_class_076); }
const Pipeline *                        storeLNode::pipeline() const { return (&pipeline_class_076); }

const Pipeline *                    storeimmL0Node::pipeline_class() { return (&pipeline_class_075); }
const Pipeline *                    storeimmL0Node::pipeline() const { return (&pipeline_class_075); }

const Pipeline *                        storePNode::pipeline_class() { return (&pipeline_class_076); }
const Pipeline *                        storePNode::pipeline() const { return (&pipeline_class_076); }

const Pipeline *                    storeimmP0Node::pipeline_class() { return (&pipeline_class_075); }
const Pipeline *                    storeimmP0Node::pipeline() const { return (&pipeline_class_075); }

const Pipeline *                        storeNNode::pipeline_class() { return (&pipeline_class_076); }
const Pipeline *                        storeNNode::pipeline() const { return (&pipeline_class_076); }

const Pipeline *                    storeImmN0Node::pipeline_class() { return (&pipeline_class_076); }
const Pipeline *                    storeImmN0Node::pipeline() const { return (&pipeline_class_076); }

const Pipeline *                        storeFNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                        storeFNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                        storeDNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                        storeDNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                   storeNKlassNode::pipeline_class() { return (&pipeline_class_076); }
const Pipeline *                   storeNKlassNode::pipeline() const { return (&pipeline_class_076); }

const Pipeline *                     prefetchrNode::pipeline_class() { return (&pipeline_class_072); }
const Pipeline *                     prefetchrNode::pipeline() const { return (&pipeline_class_072); }

const Pipeline *                     prefetchwNode::pipeline_class() { return (&pipeline_class_072); }
const Pipeline *                     prefetchwNode::pipeline() const { return (&pipeline_class_072); }

const Pipeline *                   prefetchntaNode::pipeline_class() { return (&pipeline_class_072); }
const Pipeline *                   prefetchntaNode::pipeline() const { return (&pipeline_class_072); }

const Pipeline *                loadB_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                loadB_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *              loadB2L_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *              loadB2L_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *               loadUB_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *               loadUB_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *             loadUB2L_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *             loadUB2L_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                loadS_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                loadS_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *               loadUS_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *               loadUS_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *             loadUS2L_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *             loadUS2L_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *              loadS2L_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *              loadS2L_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                loadI_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                loadI_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *             loadUI2L_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *             loadUI2L_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                loadL_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                loadL_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                loadP_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                loadP_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                loadN_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                loadN_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                loadF_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                loadF_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                loadD_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                loadD_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *               storeB_volatileNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *               storeB_volatileNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *               storeC_volatileNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *               storeC_volatileNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *               storeI_volatileNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *               storeI_volatileNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *               storeL_volatileNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *               storeL_volatileNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *               storeP_volatileNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *               storeP_volatileNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *               storeN_volatileNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *               storeN_volatileNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *               storeF_volatileNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *               storeF_volatileNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *               storeD_volatileNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *               storeD_volatileNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *             bytes_reverse_intNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *             bytes_reverse_intNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *            bytes_reverse_longNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *            bytes_reverse_longNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *  bytes_reverse_unsigned_shortNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *  bytes_reverse_unsigned_shortNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *           bytes_reverse_shortNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *           bytes_reverse_shortNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *            countLeadingZerosINode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *            countLeadingZerosINode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *            countLeadingZerosLNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *            countLeadingZerosLNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *           countTrailingZerosINode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *           countTrailingZerosINode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *           countTrailingZerosLNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *           countTrailingZerosLNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                     popCountINode::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *                     popCountINode::pipeline() const { return (&pipeline_class_084); }

const Pipeline *                 popCountI_memNode::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *                 popCountI_memNode::pipeline() const { return (&pipeline_class_084); }

const Pipeline *                     popCountLNode::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *                     popCountLNode::pipeline() const { return (&pipeline_class_084); }

const Pipeline *                 popCountL_memNode::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *                 popCountL_memNode::pipeline() const { return (&pipeline_class_084); }

const Pipeline *                    load_fenceNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                    load_fenceNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *    unnecessary_membar_acquireNode::pipeline_class() { return (&pipeline_class_083); }
const Pipeline *    unnecessary_membar_acquireNode::pipeline() const { return (&pipeline_class_083); }

const Pipeline *                membar_acquireNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                membar_acquireNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *           membar_acquire_lockNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *           membar_acquire_lockNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                   store_fenceNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                   store_fenceNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *    unnecessary_membar_releaseNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *    unnecessary_membar_releaseNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                membar_releaseNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                membar_releaseNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *             membar_storestoreNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *             membar_storestoreNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *           membar_release_lockNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *           membar_release_lockNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *   unnecessary_membar_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *   unnecessary_membar_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *               membar_volatileNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *               membar_volatileNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                       castX2PNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                       castX2PNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                       castP2XNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                       castP2XNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                       convP2INode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                       convP2INode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                       convN2INode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                       convN2INode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                  shenandoahRBNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                  shenandoahRBNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                 encodeHeapOopNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                 encodeHeapOopNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *        encodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *        encodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                 decodeHeapOopNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                 decodeHeapOopNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *        decodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *        decodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *          encodeKlass_not_nullNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *          encodeKlass_not_nullNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *          decodeKlass_not_nullNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *          decodeKlass_not_nullNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                   checkCastPPNode::pipeline_class() { return (&pipeline_class_083); }
const Pipeline *                   checkCastPPNode::pipeline() const { return (&pipeline_class_083); }

const Pipeline *                        castPPNode::pipeline_class() { return (&pipeline_class_083); }
const Pipeline *                        castPPNode::pipeline() const { return (&pipeline_class_083); }

const Pipeline *                        castIINode::pipeline_class() { return (&pipeline_class_083); }
const Pipeline *                        castIINode::pipeline() const { return (&pipeline_class_083); }

const Pipeline *                   loadPLockedNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                   loadPLockedNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *             storePConditionalNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *             storePConditionalNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *             storeLConditionalNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *             storeLConditionalNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *             storeIConditionalNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *             storeIConditionalNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *               compareAndSwapINode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *               compareAndSwapINode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *               compareAndSwapLNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *               compareAndSwapLNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *               compareAndSwapPNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *               compareAndSwapPNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *    compareAndSwapP_shenandoahNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *    compareAndSwapP_shenandoahNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *               compareAndSwapNNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *               compareAndSwapNNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *    compareAndSwapN_shenandoahNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *    compareAndSwapN_shenandoahNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *            compareAndSwapIAcqNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *            compareAndSwapIAcqNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *            compareAndSwapLAcqNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *            compareAndSwapLAcqNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *            compareAndSwapPAcqNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *            compareAndSwapPAcqNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline * compareAndSwapPAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline * compareAndSwapPAcq_shenandoahNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *            compareAndSwapNAcqNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *            compareAndSwapNAcqNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline * compareAndSwapNAcq_shenandoahNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline * compareAndSwapNAcq_shenandoahNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *                  get_and_setINode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                  get_and_setINode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                  get_and_setLNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                  get_and_setLNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                  get_and_setNNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                  get_and_setNNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                  get_and_setPNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                  get_and_setPNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                  get_and_addLNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                  get_and_addLNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *           get_and_addL_no_resNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *           get_and_addL_no_resNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                 get_and_addLiNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                 get_and_addLiNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *          get_and_addLi_no_resNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *          get_and_addLi_no_resNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                  get_and_addINode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                  get_and_addINode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *           get_and_addI_no_resNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *           get_and_addI_no_resNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                 get_and_addIiNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                 get_and_addIiNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *          get_and_addIi_no_resNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *          get_and_addIi_no_resNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                 cmovI_reg_regNode::pipeline_class() { return (&pipeline_class_064); }
const Pipeline *                 cmovI_reg_regNode::pipeline() const { return (&pipeline_class_064); }

const Pipeline *                cmovUI_reg_regNode::pipeline_class() { return (&pipeline_class_064); }
const Pipeline *                cmovUI_reg_regNode::pipeline() const { return (&pipeline_class_064); }

const Pipeline *                cmovI_zero_regNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *                cmovI_zero_regNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *               cmovUI_zero_regNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *               cmovUI_zero_regNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *                cmovI_reg_zeroNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *                cmovI_reg_zeroNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *               cmovUI_reg_zeroNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *               cmovUI_reg_zeroNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *            cmovI_reg_zero_oneNode::pipeline_class() { return (&pipeline_class_063); }
const Pipeline *            cmovI_reg_zero_oneNode::pipeline() const { return (&pipeline_class_063); }

const Pipeline *           cmovUI_reg_zero_oneNode::pipeline_class() { return (&pipeline_class_063); }
const Pipeline *           cmovUI_reg_zero_oneNode::pipeline() const { return (&pipeline_class_063); }

const Pipeline *                 cmovL_reg_regNode::pipeline_class() { return (&pipeline_class_064); }
const Pipeline *                 cmovL_reg_regNode::pipeline() const { return (&pipeline_class_064); }

const Pipeline *                cmovUL_reg_regNode::pipeline_class() { return (&pipeline_class_064); }
const Pipeline *                cmovUL_reg_regNode::pipeline() const { return (&pipeline_class_064); }

const Pipeline *                cmovL_reg_zeroNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *                cmovL_reg_zeroNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *               cmovUL_reg_zeroNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *               cmovUL_reg_zeroNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *                cmovL_zero_regNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *                cmovL_zero_regNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *               cmovUL_zero_regNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *               cmovUL_zero_regNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *                 cmovP_reg_regNode::pipeline_class() { return (&pipeline_class_064); }
const Pipeline *                 cmovP_reg_regNode::pipeline() const { return (&pipeline_class_064); }

const Pipeline *                cmovUP_reg_regNode::pipeline_class() { return (&pipeline_class_064); }
const Pipeline *                cmovUP_reg_regNode::pipeline() const { return (&pipeline_class_064); }

const Pipeline *                cmovP_reg_zeroNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *                cmovP_reg_zeroNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *               cmovUP_reg_zeroNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *               cmovUP_reg_zeroNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *                cmovP_zero_regNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *                cmovP_zero_regNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *               cmovUP_zero_regNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *               cmovUP_zero_regNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *                 cmovN_reg_regNode::pipeline_class() { return (&pipeline_class_064); }
const Pipeline *                 cmovN_reg_regNode::pipeline() const { return (&pipeline_class_064); }

const Pipeline *                cmovUN_reg_regNode::pipeline_class() { return (&pipeline_class_064); }
const Pipeline *                cmovUN_reg_regNode::pipeline() const { return (&pipeline_class_064); }

const Pipeline *                cmovN_reg_zeroNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *                cmovN_reg_zeroNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *               cmovUN_reg_zeroNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *               cmovUN_reg_zeroNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *                cmovN_zero_regNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *                cmovN_zero_regNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *               cmovUN_zero_regNode::pipeline_class() { return (&pipeline_class_065); }
const Pipeline *               cmovUN_zero_regNode::pipeline() const { return (&pipeline_class_065); }

const Pipeline *                     cmovF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                     cmovF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    cmovUF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    cmovUF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                     cmovD_regNode::pipeline_class() { return (&pipeline_class_018); }
const Pipeline *                     cmovD_regNode::pipeline() const { return (&pipeline_class_018); }

const Pipeline *                    cmovUD_regNode::pipeline_class() { return (&pipeline_class_018); }
const Pipeline *                    cmovUD_regNode::pipeline() const { return (&pipeline_class_018); }

const Pipeline *                  addI_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  addI_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  addI_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  addI_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *              addI_reg_imm_i2lNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *              addI_reg_imm_i2lNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                  addP_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  addP_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              addP_reg_reg_extNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              addP_reg_reg_extNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              addP_reg_reg_lslNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *              addP_reg_reg_lslNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        addP_reg_reg_ext_shiftNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        addP_reg_reg_ext_shiftNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *                    lshift_extNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                    lshift_extNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                  addP_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  addP_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                  addL_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  addL_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  addL_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  addL_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                  subI_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  subI_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  subI_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  subI_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                  subL_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  subL_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  subL_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  subL_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                      negI_regNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                      negI_regNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                      negL_regNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                      negL_regNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                          mulINode::pipeline_class() { return (&pipeline_class_066); }
const Pipeline *                          mulINode::pipeline() const { return (&pipeline_class_066); }

const Pipeline *                         smulINode::pipeline_class() { return (&pipeline_class_066); }
const Pipeline *                         smulINode::pipeline() const { return (&pipeline_class_066); }

const Pipeline *                       smulI_0Node::pipeline_class() { return (&pipeline_class_066); }
const Pipeline *                       smulI_0Node::pipeline() const { return (&pipeline_class_066); }

const Pipeline *                          mulLNode::pipeline_class() { return (&pipeline_class_068); }
const Pipeline *                          mulLNode::pipeline() const { return (&pipeline_class_068); }

const Pipeline *                   mulHiL_rRegNode::pipeline_class() { return (&pipeline_class_068); }
const Pipeline *                   mulHiL_rRegNode::pipeline() const { return (&pipeline_class_068); }

const Pipeline *                         maddINode::pipeline_class() { return (&pipeline_class_067); }
const Pipeline *                         maddINode::pipeline() const { return (&pipeline_class_067); }

const Pipeline *                       maddI_0Node::pipeline_class() { return (&pipeline_class_067); }
const Pipeline *                       maddI_0Node::pipeline() const { return (&pipeline_class_067); }

const Pipeline *                         msubINode::pipeline_class() { return (&pipeline_class_067); }
const Pipeline *                         msubINode::pipeline() const { return (&pipeline_class_067); }

const Pipeline *                         maddLNode::pipeline_class() { return (&pipeline_class_069); }
const Pipeline *                         maddLNode::pipeline() const { return (&pipeline_class_069); }

const Pipeline *                       maddL_0Node::pipeline_class() { return (&pipeline_class_069); }
const Pipeline *                       maddL_0Node::pipeline() const { return (&pipeline_class_069); }

const Pipeline *                         msubLNode::pipeline_class() { return (&pipeline_class_069); }
const Pipeline *                         msubLNode::pipeline() const { return (&pipeline_class_069); }

const Pipeline *                          divINode::pipeline_class() { return (&pipeline_class_070); }
const Pipeline *                          divINode::pipeline() const { return (&pipeline_class_070); }

const Pipeline *                   signExtractNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                   signExtractNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                     div2RoundNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                     div2RoundNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                   div2Round_0Node::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                   div2Round_0Node::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                          divLNode::pipeline_class() { return (&pipeline_class_071); }
const Pipeline *                          divLNode::pipeline() const { return (&pipeline_class_071); }

const Pipeline *                  signExtractLNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                  signExtractLNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                    div2RoundLNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                    div2RoundLNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                  div2RoundL_0Node::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                  div2RoundL_0Node::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                          modINode::pipeline_class() { return (&pipeline_class_070); }
const Pipeline *                          modINode::pipeline() const { return (&pipeline_class_070); }

const Pipeline *                          modLNode::pipeline_class() { return (&pipeline_class_071); }
const Pipeline *                          modLNode::pipeline() const { return (&pipeline_class_071); }

const Pipeline *               lShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *               lShiftI_reg_regNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *               lShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *               lShiftI_reg_immNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *              urShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *              urShiftI_reg_regNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *              urShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *              urShiftI_reg_immNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *               rShiftI_reg_regNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *               rShiftI_reg_regNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *               rShiftI_reg_immNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *               rShiftI_reg_immNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *               lShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *               lShiftL_reg_regNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *               lShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *               lShiftL_reg_immNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *              urShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *              urShiftL_reg_regNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *              urShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *              urShiftL_reg_immNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *              urShiftP_reg_immNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *              urShiftP_reg_immNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *               rShiftL_reg_regNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *               rShiftL_reg_regNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *               rShiftL_reg_immNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *               rShiftL_reg_immNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                  regL_not_regNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                  regL_not_regNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                  regI_not_regNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                  regI_not_regNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *              AndI_reg_not_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              AndI_reg_not_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            AndI_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            AndI_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              AndL_reg_not_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              AndL_reg_not_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            AndL_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            AndL_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *               OrI_reg_not_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *               OrI_reg_not_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *             OrI_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *             OrI_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *               OrL_reg_not_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *               OrL_reg_not_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *             OrL_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *             OrL_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              XorI_reg_not_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              XorI_reg_not_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            XorI_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            XorI_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              XorL_reg_not_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              XorL_reg_not_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            XorL_reg_not_reg_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            XorL_reg_not_reg_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *      AndI_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *      AndI_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *    AndI_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *    AndI_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *      AndL_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *      AndL_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *    AndL_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *    AndL_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       AndI_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       AndI_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     AndI_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     AndI_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       AndL_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       AndL_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     AndL_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     AndL_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       AndI_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       AndI_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     AndI_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     AndI_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       AndL_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       AndL_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     AndL_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     AndL_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *      XorI_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *      XorI_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *    XorI_reg_URShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *    XorI_reg_URShift_not_reg_1Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *    XorI_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *    XorI_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *    XorI_reg_URShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *    XorI_reg_URShift_not_reg_2Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *      XorL_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *      XorL_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *    XorL_reg_URShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *    XorL_reg_URShift_not_reg_1Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *    XorL_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *    XorL_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *    XorL_reg_URShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *    XorL_reg_URShift_not_reg_2Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       XorI_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       XorI_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorI_reg_RShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorI_reg_RShift_not_reg_1Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorI_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorI_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorI_reg_RShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorI_reg_RShift_not_reg_2Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       XorL_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       XorL_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorL_reg_RShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorL_reg_RShift_not_reg_1Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorL_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorL_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorL_reg_RShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorL_reg_RShift_not_reg_2Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       XorI_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       XorI_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorI_reg_LShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorI_reg_LShift_not_reg_1Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorI_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorI_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorI_reg_LShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorI_reg_LShift_not_reg_2Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       XorL_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       XorL_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorL_reg_LShift_not_reg_1Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorL_reg_LShift_not_reg_1Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorL_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorL_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     XorL_reg_LShift_not_reg_2Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     XorL_reg_LShift_not_reg_2Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       OrI_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       OrI_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     OrI_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     OrI_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *       OrL_reg_URShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *       OrL_reg_URShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *     OrL_reg_URShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *     OrL_reg_URShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        OrI_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        OrI_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *      OrI_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *      OrI_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        OrL_reg_RShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        OrL_reg_RShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *      OrL_reg_RShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *      OrL_reg_RShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        OrI_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        OrI_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *      OrI_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *      OrI_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        OrL_reg_LShift_not_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        OrL_reg_LShift_not_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *      OrL_reg_LShift_not_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *      OrL_reg_LShift_not_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          AndI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          AndI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        AndI_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        AndI_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          AndL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          AndL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        AndL_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        AndL_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           AndI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           AndI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         AndI_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         AndI_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           AndL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           AndL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         AndL_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         AndL_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           AndI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           AndI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         AndI_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         AndI_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           AndL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           AndL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         AndL_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         AndL_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          XorI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          XorI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        XorI_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        XorI_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          XorL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          XorL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        XorL_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        XorL_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           XorI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           XorI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         XorI_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         XorI_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           XorL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           XorL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         XorL_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         XorL_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           XorI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           XorI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         XorI_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         XorI_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           XorL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           XorL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         XorL_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         XorL_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           OrI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           OrI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         OrI_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         OrI_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           OrL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           OrL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         OrL_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         OrL_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *            OrI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *            OrI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          OrI_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          OrI_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *            OrL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *            OrL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          OrL_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          OrL_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *            OrI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *            OrI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          OrI_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          OrI_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *            OrL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *            OrL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          OrL_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          OrL_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          AddI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          AddI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        AddI_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        AddI_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          AddL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          AddL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *        AddL_reg_URShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *        AddL_reg_URShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           AddI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           AddI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         AddI_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         AddI_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           AddL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           AddL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         AddL_reg_RShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         AddL_reg_RShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           AddI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           AddI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         AddI_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         AddI_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           AddL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           AddL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *         AddL_reg_LShift_reg_0Node::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *         AddL_reg_LShift_reg_0Node::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          SubI_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          SubI_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *          SubL_reg_URShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *          SubL_reg_URShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           SubI_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           SubI_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           SubL_reg_RShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           SubL_reg_RShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           SubI_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           SubI_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *           SubL_reg_LShift_regNode::pipeline_class() { return (&pipeline_class_054); }
const Pipeline *           SubL_reg_LShift_regNode::pipeline() const { return (&pipeline_class_054); }

const Pipeline *                         sbfmLNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                         sbfmLNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                        sbfmwINode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                        sbfmwINode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                         ubfmLNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                         ubfmLNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                        ubfmwINode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                        ubfmwINode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                        ubfxwINode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                        ubfxwINode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                         ubfxLNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                         ubfxLNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                  ubfxIConvI2LNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *                  ubfxIConvI2LNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                       extrOrLNode::pipeline_class() { return (&pipeline_class_057); }
const Pipeline *                       extrOrLNode::pipeline() const { return (&pipeline_class_057); }

const Pipeline *                     extrOrL_0Node::pipeline_class() { return (&pipeline_class_057); }
const Pipeline *                     extrOrL_0Node::pipeline() const { return (&pipeline_class_057); }

const Pipeline *                       extrOrINode::pipeline_class() { return (&pipeline_class_057); }
const Pipeline *                       extrOrINode::pipeline() const { return (&pipeline_class_057); }

const Pipeline *                     extrOrI_0Node::pipeline_class() { return (&pipeline_class_057); }
const Pipeline *                     extrOrI_0Node::pipeline() const { return (&pipeline_class_057); }

const Pipeline *                      extrAddLNode::pipeline_class() { return (&pipeline_class_057); }
const Pipeline *                      extrAddLNode::pipeline() const { return (&pipeline_class_057); }

const Pipeline *                    extrAddL_0Node::pipeline_class() { return (&pipeline_class_057); }
const Pipeline *                    extrAddL_0Node::pipeline() const { return (&pipeline_class_057); }

const Pipeline *                      extrAddINode::pipeline_class() { return (&pipeline_class_057); }
const Pipeline *                      extrAddINode::pipeline() const { return (&pipeline_class_057); }

const Pipeline *                    extrAddI_0Node::pipeline_class() { return (&pipeline_class_057); }
const Pipeline *                    extrAddI_0Node::pipeline() const { return (&pipeline_class_057); }

const Pipeline *                     rolL_rRegNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *                     rolL_rRegNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *                     rolI_rRegNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *                     rolI_rRegNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *                     rorL_rRegNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *                     rorL_rRegNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *                     rorI_rRegNode::pipeline_class() { return (&pipeline_class_056); }
const Pipeline *                     rorI_rRegNode::pipeline() const { return (&pipeline_class_056); }

const Pipeline *                       AddExtINode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                       AddExtINode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                     AddExtI_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                     AddExtI_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                       SubExtINode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                       SubExtINode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  AddExtI_sxthNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  AddExtI_sxthNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                AddExtI_sxth_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                AddExtI_sxth_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  AddExtI_sxtbNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  AddExtI_sxtbNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                AddExtI_sxtb_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                AddExtI_sxtb_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  AddExtI_uxtbNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  AddExtI_uxtbNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                AddExtI_uxtb_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                AddExtI_uxtb_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  AddExtL_sxthNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  AddExtL_sxthNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                AddExtL_sxth_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                AddExtL_sxth_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  AddExtL_sxtwNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  AddExtL_sxtwNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                AddExtL_sxtw_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                AddExtL_sxtw_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  AddExtL_sxtbNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  AddExtL_sxtbNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                AddExtL_sxtb_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                AddExtL_sxtb_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  AddExtL_uxtbNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  AddExtL_uxtbNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                AddExtL_uxtb_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                AddExtL_uxtb_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              AddExtI_uxtb_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              AddExtI_uxtb_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            AddExtI_uxtb_and_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            AddExtI_uxtb_and_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              AddExtI_uxth_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              AddExtI_uxth_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            AddExtI_uxth_and_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            AddExtI_uxth_and_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              AddExtL_uxtb_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              AddExtL_uxtb_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            AddExtL_uxtb_and_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            AddExtL_uxtb_and_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              AddExtL_uxth_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              AddExtL_uxth_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            AddExtL_uxth_and_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            AddExtL_uxth_and_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              AddExtL_uxtw_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              AddExtL_uxtw_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            AddExtL_uxtw_and_0Node::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *            AddExtL_uxtw_and_0Node::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              SubExtI_uxtb_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              SubExtI_uxtb_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              SubExtI_uxth_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              SubExtI_uxth_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              SubExtL_uxtb_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              SubExtL_uxtb_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              SubExtL_uxth_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              SubExtL_uxth_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *              SubExtL_uxtw_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *              SubExtL_uxtw_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  addF_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  addF_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  addD_reg_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                  addD_reg_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                  subF_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  subF_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  subD_reg_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                  subD_reg_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                  mulF_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  mulF_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  mulD_reg_regNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                  mulD_reg_regNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                  divF_reg_regNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                  divF_reg_regNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                  divD_reg_regNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                  divD_reg_regNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  negF_reg_regNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                  negF_reg_regNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                  negD_reg_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *                  negD_reg_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *                      absF_regNode::pipeline_class() { return (&pipeline_class_003); }
const Pipeline *                      absF_regNode::pipeline() const { return (&pipeline_class_003); }

const Pipeline *                      absD_regNode::pipeline_class() { return (&pipeline_class_004); }
const Pipeline *                      absD_regNode::pipeline() const { return (&pipeline_class_004); }

const Pipeline *                     sqrtD_regNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                     sqrtD_regNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                     sqrtF_regNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                     sqrtF_regNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  andI_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  andI_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  andI_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  andI_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                   orI_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                   orI_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                   orI_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                   orI_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                  xorI_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  xorI_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  xorI_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  xorI_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                  andL_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  andL_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  andL_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  andL_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                   orL_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                   orL_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                   orL_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                   orL_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *                  xorL_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  xorL_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  xorL_reg_immNode::pipeline_class() { return (&pipeline_class_059); }
const Pipeline *                  xorL_reg_immNode::pipeline() const { return (&pipeline_class_059); }

const Pipeline *               convI2L_reg_regNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *               convI2L_reg_regNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *              convUI2L_reg_regNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *              convUI2L_reg_regNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                   convL2I_regNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                   convL2I_regNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                       convI2BNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                       convI2BNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                       convP2BNode::pipeline_class() { return (&pipeline_class_058); }
const Pipeline *                       convP2BNode::pipeline() const { return (&pipeline_class_058); }

const Pipeline *                   convD2F_regNode::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                   convD2F_regNode::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                   convF2D_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                   convF2D_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               convF2I_reg_regNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *               convF2I_reg_regNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *               convF2L_reg_regNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *               convF2L_reg_regNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *               convI2F_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *               convI2F_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *               convL2F_reg_regNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *               convL2F_reg_regNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *               convD2I_reg_regNode::pipeline_class() { return (&pipeline_class_011); }
const Pipeline *               convD2I_reg_regNode::pipeline() const { return (&pipeline_class_011); }

const Pipeline *               convD2L_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               convD2L_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               convI2D_reg_regNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               convI2D_reg_regNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *               convL2D_reg_regNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *               convL2D_reg_regNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *             MoveF2I_stack_regNode::pipeline_class() { return (&pipeline_class_074); }
const Pipeline *             MoveF2I_stack_regNode::pipeline() const { return (&pipeline_class_074); }

const Pipeline *             MoveI2F_stack_regNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *             MoveI2F_stack_regNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *             MoveD2L_stack_regNode::pipeline_class() { return (&pipeline_class_074); }
const Pipeline *             MoveD2L_stack_regNode::pipeline() const { return (&pipeline_class_074); }

const Pipeline *             MoveL2D_stack_regNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *             MoveL2D_stack_regNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *             MoveF2I_reg_stackNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *             MoveF2I_reg_stackNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *             MoveI2F_reg_stackNode::pipeline_class() { return (&pipeline_class_077); }
const Pipeline *             MoveI2F_reg_stackNode::pipeline() const { return (&pipeline_class_077); }

const Pipeline *             MoveD2L_reg_stackNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *             MoveD2L_reg_stackNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *             MoveL2D_reg_stackNode::pipeline_class() { return (&pipeline_class_077); }
const Pipeline *             MoveL2D_reg_stackNode::pipeline() const { return (&pipeline_class_077); }

const Pipeline *               MoveF2I_reg_regNode::pipeline_class() { return (&pipeline_class_007); }
const Pipeline *               MoveF2I_reg_regNode::pipeline() const { return (&pipeline_class_007); }

const Pipeline *               MoveI2F_reg_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *               MoveI2F_reg_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *               MoveD2L_reg_regNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               MoveD2L_reg_regNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               MoveL2D_reg_regNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *               MoveL2D_reg_regNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *            clearArray_reg_regNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *            clearArray_reg_regNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *            clearArray_imm_regNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *            clearArray_imm_regNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *          overflowAddI_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *          overflowAddI_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *          overflowAddI_reg_immNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *          overflowAddI_reg_immNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *          overflowAddL_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *          overflowAddL_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *          overflowAddL_reg_immNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *          overflowAddL_reg_immNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *          overflowSubI_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *          overflowSubI_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *          overflowSubI_reg_immNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *          overflowSubI_reg_immNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *          overflowSubL_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *          overflowSubL_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *          overflowSubL_reg_immNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *          overflowSubL_reg_immNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *              overflowNegI_regNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *              overflowNegI_regNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *              overflowNegL_regNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *              overflowNegL_regNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *              overflowMulI_regNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *              overflowMulI_regNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *       overflowMulI_reg_branchNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *       overflowMulI_reg_branchNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *              overflowMulL_regNode::pipeline_class() { return (&pipeline_class_082); }
const Pipeline *              overflowMulL_regNode::pipeline() const { return (&pipeline_class_082); }

const Pipeline *       overflowMulL_reg_branchNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *       overflowMulL_reg_branchNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                 compI_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *                 compI_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *               compI_reg_immI0Node::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *               compI_reg_immI0Node::pipeline() const { return (&pipeline_class_062); }

const Pipeline *          compI_reg_immIAddSubNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *          compI_reg_immIAddSubNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                compI_reg_immINode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *                compI_reg_immINode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                 compU_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *                 compU_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *               compU_reg_immI0Node::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *               compU_reg_immI0Node::pipeline() const { return (&pipeline_class_062); }

const Pipeline *          compU_reg_immIAddSubNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *          compU_reg_immIAddSubNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                compU_reg_immINode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *                compU_reg_immINode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                 compL_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *                 compL_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *               compL_reg_immL0Node::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *               compL_reg_immL0Node::pipeline() const { return (&pipeline_class_062); }

const Pipeline *          compL_reg_immLAddSubNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *          compL_reg_immLAddSubNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                compL_reg_immLNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *                compL_reg_immLNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                compUL_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *                compUL_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *              compUL_reg_immL0Node::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *              compUL_reg_immL0Node::pipeline() const { return (&pipeline_class_062); }

const Pipeline *         compUL_reg_immLAddSubNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *         compUL_reg_immLAddSubNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *               compUL_reg_immLNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *               compUL_reg_immLNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                 compP_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *                 compP_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *                 compN_reg_regNode::pipeline_class() { return (&pipeline_class_061); }
const Pipeline *                 compN_reg_regNode::pipeline() const { return (&pipeline_class_061); }

const Pipeline *                     testP_regNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *                     testP_regNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                     testN_regNode::pipeline_class() { return (&pipeline_class_062); }
const Pipeline *                     testN_regNode::pipeline() const { return (&pipeline_class_062); }

const Pipeline *                 compF_reg_regNode::pipeline_class() { return (&pipeline_class_085); }
const Pipeline *                 compF_reg_regNode::pipeline() const { return (&pipeline_class_085); }

const Pipeline *                compF_reg_zeroNode::pipeline_class() { return (&pipeline_class_085); }
const Pipeline *                compF_reg_zeroNode::pipeline() const { return (&pipeline_class_085); }

const Pipeline *                 compD_reg_regNode::pipeline_class() { return (&pipeline_class_085); }
const Pipeline *                 compD_reg_regNode::pipeline() const { return (&pipeline_class_085); }

const Pipeline *                compD_reg_zeroNode::pipeline_class() { return (&pipeline_class_085); }
const Pipeline *                compD_reg_zeroNode::pipeline() const { return (&pipeline_class_085); }

const Pipeline *                compF3_reg_regNode::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *                compF3_reg_regNode::pipeline() const { return (&pipeline_class_084); }

const Pipeline *                compD3_reg_regNode::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *                compD3_reg_regNode::pipeline() const { return (&pipeline_class_084); }

const Pipeline *              compF3_reg_immF0Node::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *              compF3_reg_immF0Node::pipeline() const { return (&pipeline_class_084); }

const Pipeline *              compD3_reg_immD0Node::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *              compD3_reg_immD0Node::pipeline() const { return (&pipeline_class_084); }

const Pipeline *                 cmpL3_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                 cmpL3_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *             cmpLTMask_reg_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *             cmpLTMask_reg_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *            cmpLTMask_reg_zeroNode::pipeline_class() { return (&pipeline_class_055); }
const Pipeline *            cmpLTMask_reg_zeroNode::pipeline() const { return (&pipeline_class_055); }

const Pipeline *                     minI_rRegNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                     minI_rRegNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                     maxI_rRegNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                     maxI_rRegNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                        branchNode::pipeline_class() { return (&pipeline_class_078); }
const Pipeline *                        branchNode::pipeline() const { return (&pipeline_class_078); }

const Pipeline *                     branchConNode::pipeline_class() { return (&pipeline_class_079); }
const Pipeline *                     branchConNode::pipeline() const { return (&pipeline_class_079); }

const Pipeline *                    branchConUNode::pipeline_class() { return (&pipeline_class_079); }
const Pipeline *                    branchConUNode::pipeline() const { return (&pipeline_class_079); }

const Pipeline *              cmpI_imm0_branchNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *              cmpI_imm0_branchNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *              cmpL_imm0_branchNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *              cmpL_imm0_branchNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *              cmpP_imm0_branchNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *              cmpP_imm0_branchNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *              cmpN_imm0_branchNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *              cmpN_imm0_branchNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *    cmpP_narrowOop_imm0_branchNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *    cmpP_narrowOop_imm0_branchNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *             cmpUI_imm0_branchNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *             cmpUI_imm0_branchNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *             cmpUL_imm0_branchNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *             cmpUL_imm0_branchNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *              cmpL_branch_signNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *              cmpL_branch_signNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *              cmpI_branch_signNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *              cmpI_branch_signNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *               cmpL_branch_bitNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *               cmpL_branch_bitNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *               cmpI_branch_bitNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *               cmpI_branch_bitNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *          far_cmpL_branch_signNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *          far_cmpL_branch_signNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *          far_cmpI_branch_signNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *          far_cmpI_branch_signNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *           far_cmpL_branch_bitNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *           far_cmpL_branch_bitNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *           far_cmpI_branch_bitNode::pipeline_class() { return (&pipeline_class_080); }
const Pipeline *           far_cmpI_branch_bitNode::pipeline() const { return (&pipeline_class_080); }

const Pipeline *                      cmpL_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                      cmpL_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                      cmpI_andNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                      cmpI_andNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  cmpL_and_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  cmpL_and_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                  cmpI_and_regNode::pipeline_class() { return (&pipeline_class_053); }
const Pipeline *                  cmpI_and_regNode::pipeline() const { return (&pipeline_class_053); }

const Pipeline *                 branchLoopEndNode::pipeline_class() { return (&pipeline_class_078); }
const Pipeline *                 branchLoopEndNode::pipeline() const { return (&pipeline_class_078); }

const Pipeline *                branchLoopEndUNode::pipeline_class() { return (&pipeline_class_078); }
const Pipeline *                branchLoopEndUNode::pipeline() const { return (&pipeline_class_078); }

const Pipeline *                   cmpFastLockNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                   cmpFastLockNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                 cmpFastUnlockNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                 cmpFastUnlockNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *                     safePointNode::pipeline_class() { return (&pipeline_class_081); }
const Pipeline *                     safePointNode::pipeline() const { return (&pipeline_class_081); }

const Pipeline *          CallStaticJavaDirectNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *          CallStaticJavaDirectNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *    CallStaticJavaDirectHandleNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *    CallStaticJavaDirectHandleNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *         CallDynamicJavaDirectNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *         CallDynamicJavaDirectNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *             CallRuntimeDirectNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *             CallRuntimeDirectNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *                CallLeafDirectNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *                CallLeafDirectNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *            CallLeafNoFPDirectNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *            CallLeafNoFPDirectNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *                TailCalljmpIndNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *                TailCalljmpIndNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *                    TailjmpIndNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *                    TailjmpIndNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *               CreateExceptionNode::pipeline_class() { return (&pipeline_class_083); }
const Pipeline *               CreateExceptionNode::pipeline() const { return (&pipeline_class_083); }

const Pipeline *              RethrowExceptionNode::pipeline_class() { return (&pipeline_class_087); }
const Pipeline *              RethrowExceptionNode::pipeline() const { return (&pipeline_class_087); }

const Pipeline *                           RetNode::pipeline_class() { return (&pipeline_class_078); }
const Pipeline *                           RetNode::pipeline() const { return (&pipeline_class_078); }

const Pipeline *            ShouldNotReachHereNode::pipeline_class() { return (&pipeline_class_084); }
const Pipeline *            ShouldNotReachHereNode::pipeline() const { return (&pipeline_class_084); }

const Pipeline *           partialSubtypeCheckNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *           partialSubtypeCheckNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *     partialSubtypeCheckVsZeroNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *     partialSubtypeCheckVsZeroNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                string_compareNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                string_compareNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                string_indexofNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                string_indexofNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *            string_indexof_conNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *            string_indexof_conNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                 string_equalsNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                 string_equalsNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                  array_equalsNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *                  array_equalsNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *              encode_iso_arrayNode::pipeline_class() { return (&pipeline_class_086); }
const Pipeline *              encode_iso_arrayNode::pipeline() const { return (&pipeline_class_086); }

const Pipeline *                      tlsLoadPNode::pipeline_class() { return (&pipeline_class_083); }
const Pipeline *                      tlsLoadPNode::pipeline() const { return (&pipeline_class_083); }

const Pipeline *                        loadV4Node::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                        loadV4Node::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                        loadV8Node::pipeline_class() { return (&pipeline_class_049); }
const Pipeline *                        loadV8Node::pipeline() const { return (&pipeline_class_049); }

const Pipeline *                       loadV16Node::pipeline_class() { return (&pipeline_class_050); }
const Pipeline *                       loadV16Node::pipeline() const { return (&pipeline_class_050); }

const Pipeline *                       storeV4Node::pipeline_class() { return (&pipeline_class_051); }
const Pipeline *                       storeV4Node::pipeline() const { return (&pipeline_class_051); }

const Pipeline *                       storeV8Node::pipeline_class() { return (&pipeline_class_051); }
const Pipeline *                       storeV8Node::pipeline() const { return (&pipeline_class_051); }

const Pipeline *                      storeV16Node::pipeline_class() { return (&pipeline_class_052); }
const Pipeline *                      storeV16Node::pipeline() const { return (&pipeline_class_052); }

const Pipeline *                   replicate8BNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                   replicate8BNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                  replicate16BNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                  replicate16BNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *               replicate8B_immNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *               replicate8B_immNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *              replicate16B_immNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *              replicate16B_immNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                   replicate4SNode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                   replicate4SNode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                   replicate8SNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                   replicate8SNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *               replicate4S_immNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *               replicate4S_immNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *               replicate8S_immNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *               replicate8S_immNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                   replicate2INode::pipeline_class() { return (&pipeline_class_042); }
const Pipeline *                   replicate2INode::pipeline() const { return (&pipeline_class_042); }

const Pipeline *                   replicate4INode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                   replicate4INode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *               replicate2I_immNode::pipeline_class() { return (&pipeline_class_047); }
const Pipeline *               replicate2I_immNode::pipeline() const { return (&pipeline_class_047); }

const Pipeline *               replicate4I_immNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *               replicate4I_immNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                   replicate2LNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                   replicate2LNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *              replicate2L_zeroNode::pipeline_class() { return (&pipeline_class_048); }
const Pipeline *              replicate2L_zeroNode::pipeline() const { return (&pipeline_class_048); }

const Pipeline *                   replicate2FNode::pipeline_class() { return (&pipeline_class_044); }
const Pipeline *                   replicate2FNode::pipeline() const { return (&pipeline_class_044); }

const Pipeline *                   replicate4FNode::pipeline_class() { return (&pipeline_class_045); }
const Pipeline *                   replicate4FNode::pipeline() const { return (&pipeline_class_045); }

const Pipeline *                   replicate2DNode::pipeline_class() { return (&pipeline_class_046); }
const Pipeline *                   replicate2DNode::pipeline() const { return (&pipeline_class_046); }

const Pipeline *                        vadd8BNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                        vadd8BNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                       vadd16BNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                       vadd16BNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        vadd4SNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                        vadd4SNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                        vadd8SNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        vadd8SNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        vadd2INode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                        vadd2INode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                        vadd4INode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        vadd4INode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        vadd2LNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        vadd2LNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        vadd2FNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                        vadd2FNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                        vadd4FNode::pipeline_class() { return (&pipeline_class_036); }
const Pipeline *                        vadd4FNode::pipeline() const { return (&pipeline_class_036); }

const Pipeline *                        vadd2DNode::pipeline_class() { return (&pipeline_class_036); }
const Pipeline *                        vadd2DNode::pipeline() const { return (&pipeline_class_036); }

const Pipeline *                        vsub8BNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                        vsub8BNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                       vsub16BNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                       vsub16BNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        vsub4SNode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                        vsub4SNode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                        vsub8SNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        vsub8SNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        vsub2INode::pipeline_class() { return (&pipeline_class_027); }
const Pipeline *                        vsub2INode::pipeline() const { return (&pipeline_class_027); }

const Pipeline *                        vsub4INode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        vsub4INode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        vsub2LNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                        vsub2LNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                        vsub2FNode::pipeline_class() { return (&pipeline_class_035); }
const Pipeline *                        vsub2FNode::pipeline() const { return (&pipeline_class_035); }

const Pipeline *                        vsub4FNode::pipeline_class() { return (&pipeline_class_036); }
const Pipeline *                        vsub4FNode::pipeline() const { return (&pipeline_class_036); }

const Pipeline *                        vsub2DNode::pipeline_class() { return (&pipeline_class_036); }
const Pipeline *                        vsub2DNode::pipeline() const { return (&pipeline_class_036); }

const Pipeline *                        vmul4SNode::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                        vmul4SNode::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                        vmul8SNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                        vmul8SNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                        vmul2INode::pipeline_class() { return (&pipeline_class_023); }
const Pipeline *                        vmul2INode::pipeline() const { return (&pipeline_class_023); }

const Pipeline *                        vmul4INode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                        vmul4INode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                        vmul2FNode::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *                        vmul2FNode::pipeline() const { return (&pipeline_class_037); }

const Pipeline *                        vmul4FNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                        vmul4FNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        vmul2DNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                        vmul2DNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        vmla4SNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        vmla4SNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        vmla8SNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                        vmla8SNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                        vmla2INode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        vmla2INode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        vmla4INode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                        vmla4INode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                        vmls4SNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        vmls4SNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        vmls8SNode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                        vmls8SNode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                        vmls2INode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        vmls2INode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                        vmls4INode::pipeline_class() { return (&pipeline_class_026); }
const Pipeline *                        vmls4INode::pipeline() const { return (&pipeline_class_026); }

const Pipeline *                        vdiv2FNode::pipeline_class() { return (&pipeline_class_037); }
const Pipeline *                        vdiv2FNode::pipeline() const { return (&pipeline_class_037); }

const Pipeline *                        vdiv4FNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                        vdiv4FNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        vdiv2DNode::pipeline_class() { return (&pipeline_class_038); }
const Pipeline *                        vdiv2DNode::pipeline() const { return (&pipeline_class_038); }

const Pipeline *                        vand8BNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                        vand8BNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                       vand16BNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                       vand16BNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                         vor8BNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                         vor8BNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                        vor16BNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                        vor16BNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                        vxor8BNode::pipeline_class() { return (&pipeline_class_029); }
const Pipeline *                        vxor8BNode::pipeline() const { return (&pipeline_class_029); }

const Pipeline *                       vxor16BNode::pipeline_class() { return (&pipeline_class_030); }
const Pipeline *                       vxor16BNode::pipeline() const { return (&pipeline_class_030); }

const Pipeline *                    vshiftcntLNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                    vshiftcntLNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                    vshiftcntRNode::pipeline_class() { return (&pipeline_class_043); }
const Pipeline *                    vshiftcntRNode::pipeline() const { return (&pipeline_class_043); }

const Pipeline *                        vsll8BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        vsll8BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      vsll8B_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      vsll8B_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       vsll16BNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                       vsll16BNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                     vsll16B_0Node::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                     vsll16B_0Node::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                        vsrl8BNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        vsrl8BNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       vsrl16BNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                       vsrl16BNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                    vsll8B_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsll8B_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                   vsll16B_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                   vsll16B_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    vsra8B_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsra8B_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                   vsra16B_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                   vsra16B_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    vsrl8B_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsrl8B_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                   vsrl16B_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                   vsrl16B_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                        vsll4SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        vsll4SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      vsll4S_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      vsll4S_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        vsll8SNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                        vsll8SNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                      vsll8S_0Node::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                      vsll8S_0Node::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                        vsrl4SNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        vsrl4SNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        vsrl8SNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                        vsrl8SNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                    vsll4S_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsll4S_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                    vsll8S_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsll8S_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    vsra4S_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsra4S_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                    vsra8S_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsra8S_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    vsrl4S_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsrl4S_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                    vsrl8S_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsrl8S_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                        vsll2INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        vsll2INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      vsll2I_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      vsll2I_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        vsll4INode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                        vsll4INode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                      vsll4I_0Node::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                      vsll4I_0Node::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                        vsrl2INode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                        vsrl2INode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                        vsrl4INode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                        vsrl4INode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                    vsll2I_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsll2I_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                    vsll4I_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsll4I_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    vsra2I_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsra2I_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                    vsra4I_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsra4I_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    vsrl2I_immNode::pipeline_class() { return (&pipeline_class_033); }
const Pipeline *                    vsrl2I_immNode::pipeline() const { return (&pipeline_class_033); }

const Pipeline *                    vsrl4I_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsrl4I_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                        vsll2LNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                        vsll2LNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                      vsll2L_0Node::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                      vsll2L_0Node::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                        vsrl2LNode::pipeline_class() { return (&pipeline_class_032); }
const Pipeline *                        vsrl2LNode::pipeline() const { return (&pipeline_class_032); }

const Pipeline *                    vsll2L_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsll2L_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    vsra2L_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsra2L_immNode::pipeline() const { return (&pipeline_class_034); }

const Pipeline *                    vsrl2L_immNode::pipeline_class() { return (&pipeline_class_034); }
const Pipeline *                    vsrl2L_immNode::pipeline() const { return (&pipeline_class_034); }
// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DAARCH64=1
#ifndef AARCH64
#  error "AARCH64 must be defined"
#endif // AARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
